@@ -15,7 +15,7 @@ module Data.Algorithm.DiffContext
     , prettyContextDiff
     ) where
 
-import Data.Algorithm.Diff (Diff(..), getGroupedDiff)
+import Data.Algorithm.Diff (PolyDiff(..), Diff, getGroupedDiff)
 import Data.List (groupBy)
 import Data.Monoid (mappend)
 import Text.PrettyPrint (Doc, text, empty, hcat)
